pub struct U256 {
left: u128,
right: u128,
}Expand description
Duct tape two u128 together to make a 256 bit wide integer.
Fields
left: u128right: u128Implementations
Sourceimpl U256
impl U256
fn bit_set(&mut self, offset: usize)
fn non_zero(self) -> bool
Sourcefn left_roll(self, width: usize) -> Self
fn left_roll(self, width: usize) -> Self
Perform a rotate_left where the width can be different from 256 bits.
Sourcefn right_roll(self, width: usize) -> Self
fn right_roll(self, width: usize) -> Self
Perform a rotate_right where the width can be different from 256 bits.